#!/usr/bin/env python3
# _*_ coding: utf-8 _*_

__author__ = 'ChenzDNA'

from setuptools import setup, find_packages

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(name="pypadb",
      version="0.0.4",
      description='Interaction with database in a simple way',
      author="ChenzDNA",
      author_email='1007324849@qq.com',
      url='https://github.com/ChenzDNA/pypa',
      packages=find_packages(),
      long_description=long_description,
      long_description_content_type="text/markdown",
      license="Apache-2.0",
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: Apache Software License",
          "Operating System :: OS Independent"],
      python_requires='>=3.5',
      install_requires=[
          "DBUtils>=2.0.2",
          "pydantic>=1.8.2",
          "PyMySQL>=1.0.2",
      ]
      )



from pydantic import BaseModel

from conf.db_configurer import db_configurer
from conf.table_configurer import tables
from utils.conditions import Like, Limit, extra
from utils.enums import LikeEnum


class User(BaseModel):
    id: int
    account: str
    stuffs: list = []


class Stuff(BaseModel):
    user_id: int
    name: str
    count: int


if __name__ == '__main__':
    db_configurer \
        .set_host('localhost') \
        .set_user('root') \
        .set_password('123456') \
        .set_database('test') \
        .end()
    # init tables
    tables.init_tables(user=User, stuff=Stuff)
    # print(
    #     tables.user.select_many(limit=Limit(1))
    # )
    # [User(id=1, account='123456')]
    # print(
    #     tables.user.select_many(limit=Limit(0, 3))
    # )
    # [User(id=1, account='123456'), User(id=2, account='123454563466'), User(id=3, account='12gsdfhs')]
    # print(
    #     tables.user.select_like(likes=Like('account', '123', LikeEnum.R_Like))
    # )
    # Like(column, value, like_mode)
    # argument likes: Union[list[Like], Like]
    # print result [User(id=1, account='123456'), User(id=2, account='123454563466')]
    # res = tables.user.select_one(
    #     id=1,
    #     extra=extra(column=['id', 'user_id'],
    #                 data_property='stuffs',
    #                 method=tables.stuff.select_many)
    # )
    print(res)



from typing import Optional

from pydantic import BaseModel

from conf.db_configurer import db_configurer
from decorator.delete import delete
from decorator.insert import insert
from decorator.update import update


class User(BaseModel):
    id: Optional[int]
    account: str
    stuffs: list = []


class Stuff(BaseModel):
    user_id: int
    name: str
    count: int


class Test(BaseModel):
    id: Optional[int]
    content: str


@update('update test')
def ins_test():
    pass


@delete('delete from test where id=%(id)s')
def del_test(id: int):
    pass


if __name__ == '__main__':
    db_configurer \
        .set_host('localhost') \
        .set_user('root') \
        .set_password('123456') \
        .set_database('test') \
        .end()
    del_test(5)



from table.base_table import BaseTable


class TableConfigurer:
    __slots__ = ['tables']

    tables: dict[str, BaseTable]

    def __getattr__(self, item: str) -> BaseTable:
        return self.tables[item]

    def init_tables(self, **kwargs):
        self.tables = {}
        if kwargs:
            for key in kwargs:
                self.tables[key] = BaseTable(key, kwargs.get(key))


tables: TableConfigurer = TableConfigurer()



from pydantic import BaseModel

from conf.db_configurer import DbConfigurer
from decorator.select import select


class User(BaseModel):
    id: int
    account: str


@select('select * from user', data_type=User)
def get_sth_many() -> list[User]:
    pass


@select('select * from user where id = %(id)s', data_type=User)
def get_sth_one(id: int) -> User:
    pass


if __name__ == '__main__':
    # end() must be called
    DbConfigurer() \
        .set_host('localhost') \
        .set_user('root') \
        .set_password('123456') \
        .set_database('test') \
        .end()

    print(get_sth_many())
    # [User(...), User(...), ...]
    print(get_sth_one(1))
    # id=1 account='...'



import re
from typing import Optional

from pydantic import BaseModel

from conf.db_configurer import db_configurer
from decorator.insert import insert


class User(BaseModel):
    id: Optional[int]
    account: str
    stuffs: list = []


class Stuff(BaseModel):
    user_id: int
    name: str
    count: int


class Test(BaseModel):
    id: Optional[int]
    content: str


@insert('insert into test(content)')
def ins_test(wow):
    pass


if __name__ == '__main__':
    db_configurer \
        .set_host('localhost') \
        .set_user('root') \
        .set_password('123456') \
        .set_database('test') \
        .end()
    print(ins_test([Test(content='wow'), Test(content='123456')]))
    a = re.findall(r'[(](.*?)[)]', 's987f(123456))123')
    print(a)



import pymysql
from pymysql.cursors import DictCursor

if __name__ == '__main__':
    # db_configurer.DbConfigurer().end()
    # connection_pool.connection()
    database = pymysql.connect(
        host='127.0.0.1',
        port=3306,
        user='root',
        password='123456',
        database='test'
    )
    cursor = database.cursor(DictCursor)
    cursor.execute('insert into test(content) value(%s),(%s)' % ('123', '345'))
    print(database.insert_id())
    database.commit()
    a, _ = 1, 2
    print(_)



from test.select_test import User
from utils import inspect_util


def sth(a: int) -> User:
    return User(id=123, account=a)


if __name__ == '__main__':
    print(inspect_util.arg_list(sth))
    print(inspect_util.returns_type(sth))



from pydantic import BaseModel


class Sth(BaseModel):
    # __slots__ = ('id', 'name')
    id: int = 0
    name: str = '123'


def ret_li():
    li = [{'id': 10, 'name': 'sdf'}, {'id': 20, 'name': 'qwe'}]
    return [Sth(**i) for i in li]


if __name__ == '__main__':
    sth_name_li = [i.name for i in ret_li()]
    print(sth_name_li)
    print(sth_name_li[0])



from typing import Optional

from pydantic import BaseModel

from conf.db_configurer import db_configurer
from conf.table_configurer import tables


class User(BaseModel):
    id: Optional[int]
    account: str
    stuffs: list = []


class Stuff(BaseModel):
    user_id: int
    name: str
    count: int


if __name__ == '__main__':
    db_configurer \
        .set_host('localhost') \
        .set_user('root') \
        .set_password('123456') \
        .set_database('test') \
        .end()
    tables.init_tables(user=User, stuff=Stuff)
    tables.user.delete(id=20)